/* -*- Mode: indent-tabs-mode: nil; js-indent-level: 2 -*- */
/* vim: set sts=2 sw=2 et tw=80: */
"use strict";

const inIDOMUtils = Cc["@mozilla.org/inspector/dom-utils;1"].getService(Ci.inIDOMUtils);

add_task(function* testChromeThemeProperties() {
  let tab = yield BrowserTestUtils.openNewForegroundTab(gBrowser, "about:home", true);

  let manifest = {
    manifest: {
      "theme": {
        "colors": {
          // Color values copied from devedition.inc.css.
          "background_tab": [39, 43, 53], // #272b35
          "background_tab_text": [245, 247, 250], // #F5F7FA;
          "button_background": [255, 255, 255], // #ffffff
          "frame": [39, 43, 53], // #272b35
          "frame_inactive": [57, 63, 76], // #393F4C
          "tab_text": [245, 247, 250], // #f5f7fa
          "toolbar": [39, 43, 53], // #272b35
          "toolbar_bottom_separator": [0, 0, 0, .2], // rgba(0,0,0,.2)
          "toolbar_button_stroke": [25, 33, 38, .8], // rgba(25,33,38,.8)
          "toolbar_button_stroke_inactive": [25, 33, 38, .6], // rgba(25,33,38,.6)
          "toolbar_top_separator": [0, 0, 0, .2], // rgba(0,0,0,.2)
          "toolbar_vertical_separator": [95, 102, 112], // #5F6670
        },
        "tints": {
          "background_tab": [.56, .18, .04], // #07090a
          "buttons": [.64, .56, .22], // rgb(25,33,38)
        },
        "gradients": {
          "toolbar_button": "linear-gradient(rgba(25, 33, 38, 0.6), rgba(25, 33, 38, 0.6))",
          "toolbar_button_pressed": "linear-gradient(rgba(25, 33, 38, 1), rgba(25, 33, 38, 1))",
        },
      },
    },
  };
  let extension = ExtensionTestUtils.loadExtension(manifest);

  yield extension.startup();

  let document = tab.ownerDocument;
  let window = document.defaultView;

  let theme = manifest.manifest.theme;
  let style = window.getComputedStyle(document.documentElement);
  Assert.ok(style.backgroundImage, "Expected background image");
  Assert.equal(style.backgroundColor, "rgb(" + theme.colors.frame.join(", ") + ")",
    "Expected correct background color");
  Assert.equal(style.color, "rgb(" + theme.colors.tab_text.join(", ") + ")",
    "Expected correct text color");

// yield new Promise(resolve => window.setTimeout(resolve, 20000));

  // Pick a button to test colors.
  let button = document.getElementById("PanelUI-menu-button");
  inIDOMUtils.addPseudoClassLock(button, ":hover");
  style = window.getComputedStyle(button);
  dump("style: " + style.borderColor + ", " + style.backgroundImage + "\n");
  Assert.equal(style.backgroundImage, theme.gradients.toolbar_button,
    "Expected a gradient background");
  inIDOMUtils.clearPseudoClassLocks(button);

  yield extension.unload();

  yield BrowserTestUtils.removeTab(tab);
});
